@@ -212,10 +212,8 @@ public:
     /** Library */
     Library library;
 
-#ifdef THREADING_MODEL_FORK
     /** @brief Load average value */
     int loadAverage;
-#endif
 
     /** @brief Maximum number of configurations to check before bailing.
         Default is 12. (--max-configs=N) */
@@ -239,6 +237,9 @@ public:
     /** @brief plist output (--plist-output=&lt;dir&gt;) */
     std::string plistOutput;
 
+    /** @brief Extra arguments for Cppcheck Premium addon */
+    std::string premiumArgs;
+
     /** @brief Using -E for debugging purposes */
     bool preprocessOnly;
 
@@ -257,7 +258,7 @@ public:
     class CPPCHECKLIB Rule {
     public:
         Rule()
-            : tokenlist("simple")         // use simple tokenlist
+            : tokenlist("normal")         // use normal tokenlist
             , id("rule")                  // default id
             , severity(Severity::style) { // default severity
         }
