@@ -29,8 +29,6 @@
 #include <list>
 #include <map>
 #include <string>
-#include <stack>
-#include <utility>
 #include <vector>
 
 class Settings;
@@ -40,6 +38,7 @@ class Token;
 class TemplateSimplifier;
 class ErrorLogger;
 class Preprocessor;
+class VariableMap;
 
 namespace simplecpp {
     class TokenList;
@@ -59,33 +58,6 @@ class CPPCHECKLIB Tokenizer {
     friend class TestSimplifyTemplate;
     friend class TemplateSimplifier;
 
-    /** Class used in Tokenizer::setVarIdPass1 */
-    class VariableMap {
-    private:
-        std::map<std::string, int> mVariableId;
-        std::stack<std::list<std::pair<std::string,int>>> mScopeInfo;
-        mutable nonneg int mVarId;
-    public:
-        VariableMap();
-        void enterScope();
-        bool leaveScope();
-        void addVariable(const std::string &varname);
-        bool hasVariable(const std::string &varname) const;
-        std::map<std::string,int>::const_iterator find(const std::string &varname) const {
-            return mVariableId.find(varname);
-        }
-        std::map<std::string,int>::const_iterator end() const {
-            return mVariableId.end();
-        }
-        const std::map<std::string,int> &map() const {
-            return mVariableId;
-        }
-        nonneg int *getVarId() const {
-            return &mVarId;
-        }
-    };
-
-
 public:
     Tokenizer();
     Tokenizer(const Settings * settings, ErrorLogger *errorLogger);
@@ -158,14 +130,6 @@ public:
      */
     bool simplifyTokenList1(const char FileName[]);
 
-    /**
-     * Most aggressive simplification of tokenlist
-     *
-     * @return false if there is an error that requires aborting
-     * the checking of this file.
-     */
-    bool simplifyTokenList2();
-
     /**
      * If --check-headers=no has been given; then remove unneeded code in headers.
      * - All executable code.
@@ -185,30 +149,15 @@ public:
     void splitTemplateRightAngleBrackets(bool check);
 
 
-    /**
-     * Deletes dead code between 'begin' and 'end'.
-     * In general not everything can be erased, such as:
-     * - code after labels;
-     * - code outside the scope where the function is called;
-     * - code after a change of scope caused by 'switch(...);'
-     *   instructions, like 'case %any%;' or 'default;'
-     * Also, if the dead code contains a 'switch' block
-     * and inside it there's a label, the function removes all
-     * the 'switch(..)' tokens and every occurrence of 'case %any%; | default;'
-     * expression, such as the 'switch' block is reduced to a simple block.
-     *
-     * @param begin Tokens after this have a possibility to be erased.
-     * @param end Tokens before this have a possibility to be erased.
-     */
-    static void eraseDeadCode(Token *begin, const Token *end);
-
     /**
      * Calculates sizeof value for given type.
      * @param type Token which will contain e.g. "int", "*", or string.
      * @return sizeof for given type, or 0 if it can't be calculated.
      */
-    nonneg int sizeOfType(const Token *type) const;
+    nonneg int sizeOfType(const Token* type) const;
+    nonneg int sizeOfType(const std::string& type) const;
 
+    void simplifyDebug();
     /**
      * Try to determine if function parameter is passed by value by looking
      * at the function declaration.
@@ -217,33 +166,9 @@ public:
      */
     bool isFunctionParameterPassedByValue(const Token *fpar) const;
 
-    /** Simplify assignment in function call "f(x=g());" => "x=g();f(x);"
-     */
-    void simplifyAssignmentInFunctionCall();
-
     /** Simplify assignment where rhs is a block : "x=({123;});" => "{x=123;}" */
     void simplifyAssignmentBlock();
 
-    /**
-     * Simplify constant calculations such as "1+2" => "3"
-     * @return true if modifications to token-list are done.
-     *         false if no modifications are done.
-     */
-    bool simplifyCalculations();
-
-    /**
-     * Simplify dereferencing a pointer offset by a number:
-     *     "*(ptr + num)" => "ptr[num]"
-     *     "*(ptr - num)" => "ptr[-num]"
-     */
-    void simplifyOffsetPointerDereference();
-
-    /**
-     * Simplify referencing a pointer offset:
-     *     "Replace "&str[num]" => "(str + num)"
-     */
-    void simplifyOffsetPointerReference();
-
     /** Insert array size where it isn't given */
     void arraySize();
 
@@ -269,28 +194,9 @@ public:
      */
     void removeMacroInClassDef();
 
-    /** Remove unknown macro in variable declarations: PROGMEM char x; */
-    void removeMacroInVarDecl();
-
-    /** Remove redundant assignment */
-    void removeRedundantAssignment();
-
-    /** Simplifies some realloc usage like
-     * 'x = realloc (0, n);' => 'x = malloc(n);'
-     * 'x = realloc (y, 0);' => 'x = 0; free(y);'
-     */
-    void simplifyRealloc();
-
     /** Add parentheses for sizeof: sizeof x => sizeof(x) */
     void sizeofAddParentheses();
 
-    /**
-     * Replace sizeof() to appropriate size.
-     * @return true if modifications to token-list are done.
-     *         false if no modifications are done.
-     */
-    bool simplifySizeof();
-
     /**
      * Simplify variable declarations (split up)
      * \param only_k_r_fpar Only simplify K&R function parameters
@@ -305,20 +211,6 @@ public:
     void simplifyInitVar();
     static Token* initVar(Token* tok);
 
-    /**
-     * Simplify easy constant '?:' operation
-     * Example: 0 ? (2/0) : 0 => 0
-     * @return true if something is modified
-     *         false if nothing is done.
-     */
-    bool simplifyConstTernaryOp();
-
-    /**
-     * Simplify compound assignments
-     * Example: ";a+=b;" => ";a=a+b;"
-     */
-    void simplifyCompoundAssignment();
-
     /**
      * Simplify the location of "static" and "const" qualifiers in
      * a variable declaration or definition.
@@ -327,14 +219,6 @@ public:
      */
     void simplifyStaticConst();
 
-    /**
-     * Simplify assignments in "if" and "while" conditions
-     * Example: "if(a=b);" => "a=b;if(a);"
-     * Example: "while(a=b) { f(a); }" => "a = b; while(a){ f(a); a = b; }"
-     * Example: "do { f(a); } while(a=b);" => "do { f(a); a = b; } while(a);"
-     */
-    void simplifyIfAndWhileAssign();
-
     /**
      * Simplify multiple assignments.
      * Example: "a = b = c = 0;" => "a = 0; b = 0; c = 0;"
@@ -350,14 +234,6 @@ public:
      */
     bool simplifyCAlternativeTokens();
 
-    /**
-     * Simplify comma into a semicolon when possible:
-     * - "delete a, delete b" => "delete a; delete b;"
-     * - "a = 0, b = 0;" => "a = 0; b = 0;"
-     * - "return a(), b;" => "a(); return b;"
-     */
-    void simplifyComma();
-
     /** Add braces to an if-block, for-block, etc.
      * @return true if no syntax errors
      */
@@ -400,85 +276,20 @@ public:
      */
     bool simplifyUsing();
 
-    /**
-     * Simplify casts
-     */
-    void simplifyCasts();
-
-    /**
-     * Change (multiple) arrays to (multiple) pointers.
-     */
-    void simplifyUndefinedSizeArray();
-
-    /**
-     * A simplify function that replaces a variable with its value in cases
-     * when the value is known. e.g. "x=10; if(x)" => "x=10;if(10)"
-     *
-     * @return true if modifications to token-list are done.
-     *         false if no modifications are done.
-     */
-    bool simplifyKnownVariables();
-
-    /**
-     * Utility function for simplifyKnownVariables. Get data about an
-     * assigned variable.
-     */
-    static bool simplifyKnownVariablesGetData(nonneg int varid, Token **_tok2, Token **_tok3, std::string &value, nonneg int &valueVarId, bool &valueIsPointer, bool floatvar);
-
-    /**
-     * utility function for simplifyKnownVariables. Perform simplification
-     * of a given variable
-     */
-    bool simplifyKnownVariablesSimplify(Token **tok2, Token *tok3, nonneg int varid, const std::string &structname, std::string &value, nonneg int valueVarId, bool valueIsPointer, const Token * const valueToken, int indentlevel) const;
-
     /** Simplify useless C++ empty namespaces, like: 'namespace %name% { }'*/
     void simplifyEmptyNamespaces();
 
-    /** Simplify redundant code placed after control flow statements :
-     * 'return', 'throw', 'goto', 'break' and 'continue'
-     */
-    void simplifyFlowControl();
-
-    /** Expand nested strcat() calls. */
-    void simplifyNestedStrcat();
-
     /** Simplify "if else" */
     void elseif();
 
     /** Simplify C++17/C++20 if/switch/for initialization expression */
     void simplifyIfSwitchForInit();
 
-    /** Simplify conditions
-     * @return true if something is modified
-     *         false if nothing is done.
-     */
-    bool simplifyConditions();
-
-    /** Remove redundant code, e.g. if( false ) { int a; } should be
-     * removed, because it is never executed.
-     * @return true if something is modified
-     *         false if nothing is done.
-     */
-    bool removeRedundantConditions();
-
-    /**
-     * Remove redundant for:
-     * "for (x=0;x<1;x++) { }" => "{ x = 1; }"
-     */
-    void removeRedundantFor();
-
-
     /**
      * Reduces "; ;" to ";", except in "( ; ; )"
      */
     void removeRedundantSemicolons();
 
-    /** Simplify function calls - constant return value
-     * @return true if something is modified
-     *         false if nothing is done.
-     */
-    bool simplifyFunctionReturn();
-
     /** Struct simplification
      * "struct S { } s;" => "struct S { }; S s;"
      */
@@ -496,11 +307,6 @@ public:
      */
     bool simplifyRedundantParentheses();
 
-    void simplifyCharAt();
-
-    /** Simplify references */
-    void simplifyReference();
-
     /**
      * Simplify functions like "void f(x) int x; {"
      * into "void f(int x) {"
@@ -546,16 +352,6 @@ public:
 
     void findComplicatedSyntaxErrorsInTemplates();
 
-    /**
-     * Simplify e.g. 'atol("0")' into '0'
-     */
-    void simplifyMathFunctions();
-
-    /**
-     * Simplify e.g. 'sin(0)' into '0'
-     */
-    void simplifyMathExpressions();
-
     /**
      * Modify strings in the token list by replacing hex and oct
      * values. E.g. "\x61" -> "a" and "\000" -> "\0"
@@ -592,26 +388,6 @@ public:
 
 private:
 
-    /**
-     * simplify "while (0)"
-     */
-    void simplifyWhile0();
-
-    /**
-     * Simplify while(func() && errno==EINTR)
-     */
-    void simplifyErrNoInWhile();
-
-    /**
-     * Simplify while(func(f))
-     */
-    void simplifyFuncInWhile();
-
-    /**
-     * Remove "std::" before some function names
-     */
-    void simplifyStd();
-
     /** Simplify pointer to standard type (C only) */
     void simplifyPointerToStandardType();
 
@@ -637,7 +413,7 @@ private:
 public:
 
     /** Syntax error */
-    NORETURN void syntaxError(const Token *tok, const std::string &code = "") const;
+    NORETURN void syntaxError(const Token *tok, const std::string &code = emptyString) const;
 
     /** Syntax error. Unmatched character. */
     NORETURN void unmatchedToken(const Token *tok) const;
@@ -820,25 +596,19 @@ private:
     void setVarIdClassDeclaration(const Token * const startToken,
                                   const VariableMap &variableMap,
                                   const nonneg int scopeStartVarId,
-                                  std::map<int, std::map<std::string,int>>& structMembers);
+                                  std::map<nonneg int, std::map<std::string, nonneg int>>& structMembers);
 
     void setVarIdStructMembers(Token **tok1,
-                               std::map<int, std::map<std::string, int>>& structMembers,
+                               std::map<nonneg int, std::map<std::string, nonneg int>>& structMembers,
                                nonneg int *varId) const;
 
     void setVarIdClassFunction(const std::string &classname,
                                Token * const startToken,
                                const Token * const endToken,
-                               const std::map<std::string,int> &varlist,
-                               std::map<int, std::map<std::string,int>>& structMembers,
+                               const std::map<std::string, nonneg int> &varlist,
+                               std::map<nonneg int, std::map<std::string, nonneg int>>& structMembers,
                                nonneg int *varId_);
 
-    /**
-     * Simplify e.g. 'return(strncat(temp,"a",1));' into
-     * strncat(temp,"a",1); return temp;
-     */
-    void simplifyReturnStrncat();
-
     /**
      * Output list of unknown types.
      */
@@ -866,7 +636,6 @@ public:
         return mSymbolDatabase;
     }
     void createSymbolDatabase();
-    void deleteSymbolDatabase();
 
     /** print --debug output if debug flags match the simplification:
      * 0=unknown/both simplifications
@@ -896,13 +665,6 @@ public:
         return list.front();
     }
 
-    /**
-     * Helper function to check whether number is zero (0 or 0.0 or 0E+0) or not?
-     * @param s the string to check
-     * @return true in case is is zero and false otherwise.
-     */
-    static bool isZeroNumber(const std::string &s);
-
     /**
      * Helper function to check whether number is one (1 or 0.1E+1 or 1E+0) or not?
      * @param s the string to check
@@ -910,13 +672,6 @@ public:
      */
     static bool isOneNumber(const std::string &s);
 
-    /**
-     * Helper function to check whether number is two (2 or 0.2E+1 or 2E+0) or not?
-     * @param s the string to check
-     * @return true in case is is two and false otherwise.
-     */
-    static bool isTwoNumber(const std::string &s);
-
     /**
      * Helper function to check for start of function execution scope.
      * Do not use this in checks.  Use the symbol database.
