@@ -22,12 +22,27 @@
 #include <wx/memory.h>
 #include <wx/frame.h>
 #include <wx/menu.h>
+#include <wx/regex.h>
 #include <wx/stattext.h>
 #include <wx/sizer.h>
 #include <wx/string.h>
 #include <wx/textctrl.h>
 #include <wx/propgrid/property.h>
 
+void uninitvar_wxRegEx_GetMatch(wxRegEx &obj, size_t *start, size_t *len, size_t index)
+{
+    size_t s,l;
+    size_t *sPtr,*lPtr;
+    // cppcheck-suppress uninitvar
+    (void)obj.GetMatch(&s,lPtr);
+    // TODO cppcheck-suppress uninitvar
+    (void)obj.GetMatch(sPtr,&l);
+    (void)obj.GetMatch(&s,&l);
+    (void)obj.GetMatch(start,len);
+    (void)obj.GetMatch(start,len,0);
+    (void)obj.GetMatch(start,len,index);
+}
+
 #ifdef __VISUALC__
 // Ensure no duplicateBreak warning is issued after wxLogApiError() calls.
 // This function does not terminate execution.
