@@ -18,13 +18,13 @@
 
 
 #include "checkexceptionsafety.h"
-#include "config.h"
 #include "errortypes.h"
 #include "settings.h"
 #include "testsuite.h"
 #include "tokenize.h"
 
 #include <iosfwd>
+#include <sstream>
 
 class TestExceptionSafety : public TestFixture {
 public:
@@ -33,7 +33,7 @@ public:
 private:
     Settings settings;
 
-    void run() OVERRIDE {
+    void run() override {
         settings.severity.fill();
 
         TEST_CASE(destructors);
