@@ -16,7 +16,6 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
 #include "settings.h"
 #include "testsuite.h"
 #include "testutils.h"
@@ -27,6 +26,7 @@
 
 #include <algorithm>
 #include <iosfwd>
+#include <sstream>
 #include <string>
 #include <vector>
 
@@ -45,7 +45,7 @@ private:
     std::vector<std::string> extendedOps;
     std::vector<std::string> assignmentOps;
 
-    void run() OVERRIDE {
+    void run() override {
         arithmeticalOps = { "+", "-", "*", "/", "%", "<<", ">>" };
         logicalOps = { "&&", "||", "!" };
         comparisonOps = { "==", "!=", "<", "<=", ">", ">=" };
@@ -63,7 +63,6 @@ private:
         TEST_CASE(stringTypes);
         TEST_CASE(getStrLength);
         TEST_CASE(getStrSize);
-        TEST_CASE(getCharAt);
         TEST_CASE(strValue);
         TEST_CASE(concatStr);
 
@@ -413,28 +412,6 @@ private:
         ASSERT_EQUALS(sizeof("\\"), Token::getStrSize(&tok, &settings));
     }
 
-    void getCharAt() const {
-        Token tok;
-
-        tok.str("\"asdf\"");
-        ASSERT_EQUALS("a", Token::getCharAt(&tok, 0));
-        ASSERT_EQUALS("s", Token::getCharAt(&tok, 1));
-
-        tok.str("\"a\\ts\"");
-        ASSERT_EQUALS("\\t", Token::getCharAt(&tok, 1));
-
-        tok.str("\"\"");
-        ASSERT_EQUALS("\\0", Token::getCharAt(&tok, 0));
-
-        tok.str("L\"a\\ts\"");
-        ASSERT_EQUALS("a", Token::getCharAt(&tok, 0));
-        ASSERT_EQUALS("\\t", Token::getCharAt(&tok, 1));
-
-        tok.str("u\"a\\ts\"");
-        ASSERT_EQUALS("\\t", Token::getCharAt(&tok, 1));
-        ASSERT_EQUALS("s", Token::getCharAt(&tok, 2));
-    }
-
     void strValue() const {
         Token tok;
 
@@ -1104,14 +1081,14 @@ private:
         ASSERT(t == nullptr);
     }
 
-    void findClosingBracket() {
+    void findClosingBracket() const {
         givenACodeSampleToTokenize var("template<typename X, typename...Y> struct S : public Fred<Wilma<Y...>> {}");
 
         const Token* const t = var.tokens()->next()->findClosingBracket();
         ASSERT(Token::simpleMatch(t, "> struct"));
     }
 
-    void expressionString() {
+    void expressionString() const {
         givenACodeSampleToTokenize var1("void f() { *((unsigned long long *)x) = 0; }");
         const Token *const tok1 = Token::findsimplematch(var1.tokens(), "*");
         ASSERT_EQUALS("*((unsigned long long*)x)", tok1->expressionString());
@@ -1133,7 +1110,7 @@ private:
         ASSERT_EQUALS("x=\"\\x00\\x01\\x02\\x03\\x04\\x05\\x06\\x07\"", data6.tokens()->next()->expressionString());
     }
 
-    void hasKnownIntValue() {
+    void hasKnownIntValue() const {
         // pointer might be NULL
         ValueFlow::Value v1(0);
 
